<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv-SE" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Kalkylark</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Skapa kalkylark</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Skapa ett nytt kalkylark</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Kalkylark</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Bottenjustera</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Bottenjustera innehållet i markerade celler</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Kalkylark</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Centrera</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Centrera innehållet i markerade celler</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Kalkylark</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Vänsterjustera</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Vänsterjustera innehållet i markerade celler</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Kalkylark</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Högerjustera</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Högerjustera innehållet i markerade celler</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Kalkylark</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Toppjustera</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Toppjustera innehållet i markerade celler</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Kalkylark</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Centrera vertikalt</translation>
    </message>
    <message>
      <source>Vertically center-align contents of selected cells</source>
      <translation>Centrera innehållet i markerade celler vertikalt</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Kalkylark</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Exportera kalkylark</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Exportera kalkylark till CSV-fil</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Kalkylark</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Importera kalkylark</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Importera CSV-fil till kalkylark</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Kalkylark</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Sammanfoga celler</translation>
    </message>
    <message>
      <source>Merge selected cells</source>
      <translation>Sammanfoga markerade celler</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Kalkylark</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Ange alias</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Ange alias för markerad cell</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Kalkylark</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Dela cell</translation>
    </message>
    <message>
      <source>Split previously merged cells</source>
      <translation>Dela sammanslagna celler</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Kalkylark</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Fet text</translation>
    </message>
    <message>
      <source>Set text in selected cells bold</source>
      <translation>Gör texten i markerade celler fet</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Kalkylark</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Kursiv text</translation>
    </message>
    <message>
      <source>Set text in selected cells italic</source>
      <translation>Gör texten i markerade celler kursiv</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Kalkylark</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Understruken text</translation>
    </message>
    <message>
      <source>Underline text in selected cells</source>
      <translation>Gör texten i markerade celler understruken</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom Color</source>
      <translation>Anpassad färg</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <source>Merge cells</source>
      <translation>Sammanfoga celler</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Dela cell</translation>
    </message>
    <message>
      <source>Left-align cell</source>
      <translation type="unfinished">Left-align cell</translation>
    </message>
    <message>
      <source>Center cell</source>
      <translation type="unfinished">Center cell</translation>
    </message>
    <message>
      <source>Right-align cell</source>
      <translation type="unfinished">Right-align cell</translation>
    </message>
    <message>
      <source>Top-align cell</source>
      <translation type="unfinished">Top-align cell</translation>
    </message>
    <message>
      <source>Bottom-align cell</source>
      <translation type="unfinished">Bottom-align cell</translation>
    </message>
    <message>
      <source>Vertically center cells</source>
      <translation type="unfinished">Vertically center cells</translation>
    </message>
    <message>
      <source>Set bold text</source>
      <translation type="unfinished">Set bold text</translation>
    </message>
    <message>
      <source>Set italic text</source>
      <translation type="unfinished">Set italic text</translation>
    </message>
    <message>
      <source>Set underline text</source>
      <translation type="unfinished">Set underline text</translation>
    </message>
    <message>
      <source>Create Spreadsheet</source>
      <translation type="unfinished">Create Spreadsheet</translation>
    </message>
    <message>
      <source>Set cell properties</source>
      <translation type="unfinished">Set cell properties</translation>
    </message>
    <message>
      <source>Edit cell</source>
      <translation>Redigera cell</translation>
    </message>
    <message>
      <source>Insert rows</source>
      <translation>Infoga rader</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Ta bort rader</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Infoga kolumner</translation>
    </message>
    <message>
      <source>Clear cell(s)</source>
      <translation type="unfinished">Clear cell(s)</translation>
    </message>
    <message>
      <source>Set foreground color</source>
      <translation type="unfinished">Set foreground color</translation>
    </message>
    <message>
      <source>Set background color</source>
      <translation type="unfinished">Set background color</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Cellegenskaper</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp;Färg</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Text</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Bakgrund</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;Justering</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation>Horisontell</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Vänster</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Centrum</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Höger</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation>Lodrät</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Topp</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Botten</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>&amp;Stil</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Fet</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Kursiv</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Understruken</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>Visningsenhet</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Enhetstext</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>&amp;Alias</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Alias för denna cell</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Alla (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>importera fil</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Exportera fil</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Visa kalkylark</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>Ange förgrundsfärg för cell(er)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>Anger förgrundsfärgen för cellen/cellerna</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>Ange bakgrundsfärg för cell(er)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>Anger bakgrundsfärgen för cellen/cellerna</translation>
    </message>
    <message>
      <source>Spreadsheet</source>
      <translation>Kalkylark</translation>
    </message>
    <message>
      <source>Spreadsheet does not support range selection when pasting.
Please select one cell only.</source>
      <translation>Kalkylbladet stöder inte markering av intervall när du klistrar in.
Välj endast en cell.</translation>
    </message>
    <message>
      <source>Copy &amp; Paste failed</source>
      <translation>Kopiera och klistra in misslyckades</translation>
    </message>
    <message>
      <source>Alias contains invalid characters!</source>
      <translation>Alias innehåller ogiltiga tecken!</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation>Referera till cellen via alias, till exempel
Spreadsheet.my_alias_name, istället för Spreadsheet.B1</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Svart</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Vit</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Röd</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Mörkröd</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Grön</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Mörkgrön</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Blå</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Mörkblå</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Cyan</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Mörkcyan</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Magenta</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Mörkmagenta</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Gul</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Mörkgul</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Grå</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Mörkgrå</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Ljusgrå</translation>
    </message>
    <message>
      <source>Custom Color</source>
      <translation>Anpassad färg</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Form</translation>
    </message>
    <message>
      <source>&amp;Content:</source>
      <translation>&amp;Innehåll:</translation>
    </message>
    <message>
      <source>&amp;Alias:</source>
      <translation>Alias ​​</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation>Referera till cellen via alias, till exempel
Spreadsheet.my_alias_name, istället för Spreadsheet.B1</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Namnlös</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Infoga rader</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Ta bort rader</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Infoga kolumner</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Ta bort kolumner</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Egenskaper...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Kalkylark</translation>
    </message>
  </context>
</TS>
